# Either one of gtk2, qt5, qt6. gtk3 is experimental and avoid it.
%bcond_without	qt
%define qt_ver	6

Summary:	A graphical interface for the video converter ffmpeg or avconv
Name:		winff
Version:	1.6.4
Release:	%mkrel 2
License:	GPLv3+
Group:		Video/Editors and Converters
Url:		https://github.com/WinFF/winff/
Source0:	https://github.com/WinFF/winff/archive/%{name}-%{version}.tar.gz
Source1:	winff-qt6.desktop
BuildRequires:	lazarus
BuildRequires:	dos2unix
%if %{with qt}
BuildRequires:	qt%{qt_ver}pas-devel
%endif
Requires:	ffmpeg
Requires:	xterm

%description
WinFF is a GUI for the command line video converter, FFMPEG. It will convert
most any video file that FFmpeg will convert. WinFF does multiple files in
multiple formats at one time. You can for example convert mpeg's, flv's, and
mov's, all into avi's all at once.

%if %{with qt}
%package	qt%{qt_ver}
Summary:	A Lazarus/Qt%{qt_ver} graphical interface for the video converter ffmpeg or avconv
Group:		Video/Editors and Converters
License:	GPLv3+
Requires:	%{name} >= %{version}-%{release}

%description	qt%{qt_ver}
WinFF is a GUI for the command line video converter, FFMPEG. It will convert
most any video file that FFmpeg will convert. WinFF does multiple files in
multiple formats at one time. You can for example convert mpeg's, flv's, and
mov's, all into avi's all at once.
This is WinFF for Qt written in Lazarus/Qt%{qt_ver}.
%endif

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}

# Fix EOL (Version 1.2.0)
dos2unix winff/*.txt

cp %{SOURCE1} ./winff

%build

for i in gtk2 %{?with_qt:qt%{qt_ver}}; do
  lazbuild --ws=$i winff/winff.lpr
  mv winff/winff winff/winff-$i
done
mv winff/winff-gtk2 winff/winff

%install
pushd winff
mkdir -p %{buildroot}{%{_bindir},%{_datadir}/%{name}/languages}

# Install winff binary
install -p -m 0755 %{name} %{buildroot}%{_bindir}

# Install languages
install -p -m 0644 languages/*.po %{buildroot}%{_datadir}/%{name}/languages

# Install presets
install -p -m 0644 presets.xml %{buildroot}%{_datadir}/%{name}

mkdir -p %{buildroot}{%{_datadir}/pixmaps,%{_datadir}/applications,%{_mandir}/man1}

# Install man page
install -p -m 0644 %{name}.1 %{buildroot}%{_mandir}/man1

# Install icons
install -p -m 0644 winff-icons/48x48/%{name}.png %{buildroot}%{_datadir}/pixmaps
for i in 16 24 32 48; do
	mkdir -p %{buildroot}%{_datadir}/icons/hicolor/"$i"x"$i"/apps
	install -p -m 0644 winff-icons/"$i"x"$i"/*.png %{buildroot}%{_datadir}/icons/hicolor/"$i"x"$i"/apps
done

# Desktop file
install -p -m 0644 winff.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%if %{with qt}
# Install winff binary for Qt
install -p -m 0755 %{name}-qt%{qt_ver} %{buildroot}%{_bindir}

# Desktop file for Qt-backend
install -p -m 0644 %{name}-qt%{qt_ver}.desktop %{buildroot}%{_datadir}/applications/%{name}-qt%{qt_ver}.desktop
%endif


%files
%doc winff/AUTHORS winff/*.txt winff/docs/*
%license winff/COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/*.png
%{_iconsdir}/hicolor/*/apps/winff.png
%{_mandir}/man1/*

%if %{with qt}
%files qt%{qt_ver}
%doc winff/AUTHORS winff/*.txt winff/docs/*
%license winff/COPYING
%{_bindir}/%{name}-qt%{qt_ver}
%{_datadir}/applications/%{name}-qt%{qt_ver}.desktop
%endif


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.6.4-2.mga10
+ Revision: 2224851
- Mageia 10 Mass Rebuild

* Wed Jul 10 2024 daviddavid <daviddavid> 1.6.4-1.mga10
+ Revision: 2080518
- new version: 1.6.4
- enable Lazarus/Qt6 port of winff

* Sat Jan 28 2023 wally <wally> 1.5.5-5.mga9
+ Revision: 1936637
- remove trailing spaces from description
- don't own hicolor icon dirs

* Mon Mar 28 2022 umeabot <umeabot> 1.5.5-4.mga9
+ Revision: 1831001
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.5.5-3.mga8
+ Revision: 1519421
- Mageia 8 Mass Rebuild

* Thu Oct 11 2018 pterjan <pterjan> 1.5.5-2.mga7
+ Revision: 1319431
- Add upstream patch for lazarus 1.8 support
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sat Jan 21 2017 daviddavid <daviddavid> 1.5.5-1.mga6
+ Revision: 1082794
- new version: 1.5.5
- add debian patch to generate debuginfo

* Fri Sep 30 2016 daviddavid <daviddavid> 1.5.3-3.mga6
+ Revision: 1057837
- add debian patch to add default pdf launcher to list of pdf viewers
- add debian patch to fix upstream version number in About menu
- fix some data permissions
- update and add French translation on desktop file

* Wed Feb 17 2016 umeabot <umeabot> 1.5.3-2.mga6
+ Revision: 963245
- Mageia 6 Mass Rebuild

* Fri Oct 30 2015 daviddavid <daviddavid> 1.5.3-1.mga6
+ Revision: 896809
- new version: 1.5.3

* Wed Oct 15 2014 umeabot <umeabot> 1.5.1-4.mga5
+ Revision: 747737
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
- Mageia 4 Mass Rebuild

* Sat Jun 29 2013 malo <malo> 1.5.1-1.mga4
+ Revision: 448293
- update to 1.5.1

* Sat Jun 01 2013 malo <malo> 1.5.0-1.mga4
+ Revision: 434097
- update to 1.5.0

* Mon Jan 14 2013 umeabot <umeabot> 1.4.3-2.mga3
+ Revision: 385712
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 09 2012 malo <malo> 1.4.3-1.mga3
+ Revision: 304021
- update to 1.4.3

* Sun Sep 30 2012 malo <malo> 1.4.2-2.mga3
+ Revision: 300642
- Update RPM group

* Wed Jun 20 2012 malo <malo> 1.4.2-1.mga3
+ Revision: 262242
- fix lazarus config path for build
- spec clean-up (patch from Ezim)
- update to new version after import from Mandriva
- drop patch unneeded in new version
- import from Mandriva


* Thu Feb 09 2012 Andrey Bondrov <abondrov@mandriva.org> 1.4.1-1mdv2012.0
+ Revision: 772352
- Add patch0 to remove hardcoded build target
- New version 1.4.1

* Thu Dec 22 2011 Guilherme Moro <guilherme@mandriva.com> 1.4.0-0
+ Revision: 744444
- disable debug packages
- enable generating dwarf
- updated to version 1.4.0

* Tue Nov 01 2011 Alexander Khrukin <akhrukin@mandriva.org> 1.3.2-1
+ Revision: 709261
- version bump

* Tue Nov 01 2011 Александр Казанцев <kazancas@mandriva.org> 1.3.1-3
+ Revision: 708679
+ rebuild (emptylog)

* Sat Sep 11 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.3.1-1mdv2011.0
+ Revision: 577154
- update to 1.3.1

* Fri Aug 06 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.3.0-1mdv2011.0
+ Revision: 566545
- update to 1.3.0

* Thu Feb 04 2010 Jérôme Brenier <incubusss@mandriva.org> 1.2.0-1mdv2010.1
+ Revision: 500607
- new version 1.2.0
- drop no more needed permissions fix

* Thu Dec 03 2009 Jérôme Brenier <incubusss@mandriva.org> 1.1.1-1mdv2010.1
+ Revision: 472887
--pcp option no more needed for lazbuild
- add Requires: xterm
- initial import
- Created package structure for winff.

